@@ -13,14 +13,13 @@ import warnings  # pylint: disable=unused-import
 from dataclasses import dataclass
 from typing import Any, Dict, List, NewType, Optional, Tuple, Union  # pylint: disable=unused-import
 
-from dataclasses_json import dataclass_json
+from dataclasses_json import DataClassJsonMixin
 
 from annofabapi.models import PricePlan
 
 
-@dataclass_json
 @dataclass
-class OrganizationActivity:
+class OrganizationActivity(DataClassJsonMixin):
     """"""
 
     organization_id: str
@@ -33,9 +32,8 @@ class OrganizationActivity:
     """"""
 
 
-@dataclass_json
 @dataclass
-class Organization:
+class Organization(DataClassJsonMixin):
     """"""
 
     organization_id: str
