@@ -39,6 +39,7 @@ from annofabapi.models import (
     SimpleAnnotationDetail,
     SupplementaryData,
     Task,
+    TaskStatus,
 )
 from annofabapi.parser import SimpleAnnotationDirParser, SimpleAnnotationParser
 from annofabapi.utils import _download, _log_error_response, _raise_for_status, allow_404_error, str_now
@@ -165,9 +166,7 @@ class Wrapper:
         Args:
             project_id: プロジェクトID
             dest_path: ダウンロード先のファイルパス
-            v2: True:v2形式(JSONファイル名がinput_data_id)をダウンロード.
-                False: v1形式(JSONファイル名がinput_data_name) をダウンロード.
-                v1形式はいずれ廃止される。v1形式が廃止されたら、引数v2のデフォルト値はTrueにする予定。
+            v2:  互換性を保つために残している引数。2020-10-31以降に廃止する。
 
         Returns:
             ダウンロード元のURL
@@ -176,6 +175,7 @@ class Wrapper:
         query_params = None
         if v2:
             query_params = {"v2": True}
+            logger.warning("メソッド引数`v2`は2020-10-31以降に廃止します。")
 
         _, response = self.api.get_annotation_archive(project_id, query_params=query_params)
         url = response.headers["Location"]
@@ -187,7 +187,7 @@ class Wrapper:
         """
         FullアノテーションZIPをダウンロードする。
 
-        .. deprecated:: 0.21.1
+        .. deprecated:: X
 
         Args:
             project_id: プロジェクトID
@@ -333,7 +333,7 @@ class Wrapper:
         self,
         src: TaskFrameKey,
         dest: TaskFrameKey,
-        account_id: str,
+        account_id: Optional[str] = None,
         annotation_specs_relation: Optional[AnnotationSpecsRelation] = None,
     ) -> bool:
         """
@@ -342,7 +342,7 @@ class Wrapper:
         Args:
             src: コピー元のTaskFrame情報
             dest: コピー先のTaskFrame情報
-            account_id: アノテーションを登録するユーザのアカウントID
+            account_id: アノテーションを登録するユーザのアカウントID。Noneの場合、自分自身のアカウントIDで登録する。
             annotation_specs_relation: アノテーション仕様間の紐付け情報。``get_annotation_specs_relation`` メソッドで紐付け情報を取得できる。
                 Noneの場合、コピー元のアノテーション仕様のID情報（ラベルID、属性ID、選択肢ID）を変換せずに、アノテーションをコピーします。
 
@@ -365,7 +365,7 @@ class Wrapper:
             dest.task_id,
             dest.input_data_id,
             src_details=src_annotation_details,
-            account_id=account_id,
+            account_id=account_id if account_id is not None else self.api.account_id,
             annotation_specs_relation=annotation_specs_relation,
         )
         request_body["updated_datetime"] = updated_datetime
@@ -1261,8 +1261,7 @@ class Wrapper:
         """
         複数のプロジェクトメンバを追加/更新/削除する.
 
-        Note:
-            誤って実行しないようにすること
+        .. deprecated:: 2020-01-01
 
         Args:
             project_id: プロジェクトID
@@ -1272,6 +1271,7 @@ class Wrapper:
             `putProjectMember` APIのContentのList
 
         """
+        warnings.warn("deprecated: 2021-01-01以降に廃止します。", DeprecationWarning)
 
         # 追加/更新前のプロジェクトメンバ
         dest_project_members = self.get_all_project_members(project_id)
@@ -1311,6 +1311,8 @@ class Wrapper:
         """
         複数のプロジェクトメンバに1つのロールを割り当てる。
 
+        .. deprecated:: 2020-01-01
+
         Note:
             誤って実行しないようにすること
 
@@ -1323,6 +1325,7 @@ class Wrapper:
             `putProjectMember` APIのContentのList
 
         """
+        warnings.warn("deprecated: 2021-01-01以降に廃止します。", DeprecationWarning)
 
         project_members = []
         for user_id in user_id_list:
@@ -1335,6 +1338,8 @@ class Wrapper:
         """
         複数のプロジェクトメンバを、プロジェクトから脱退させる
 
+        .. deprecated:: 2020-01-01
+
         Note:
             誤って実行しないようにすること
 
@@ -1345,6 +1350,7 @@ class Wrapper:
         Returns:
             `putProjectMember` APIのContentのList
         """
+        warnings.warn("deprecated: 2021-01-01以降に廃止します。", DeprecationWarning)
 
         project_members = []
         for user_id in user_id_list:
@@ -1363,6 +1369,8 @@ class Wrapper:
         """
         プロジェクトメンバを、別のプロジェクトにコピーする。
 
+        .. deprecated:: 2020-01-01
+
         Note:
             誤って実行しないようにすること
 
@@ -1375,6 +1383,8 @@ class Wrapper:
             `putProjectMember` APIのContentのList
 
         """
+        warnings.warn("deprecated: 2021-01-01以降に廃止します。", DeprecationWarning)
+
         src_project_members = self.get_all_project_members(src_project_id)
         dest_project_members = self.get_all_project_members(dest_project_id)
 
@@ -1448,6 +1458,222 @@ class Wrapper:
         """
         return self._get_all_objects(self.api.get_tasks, limit=200, project_id=project_id, query_params=query_params)
 
+    def change_task_status_to_working(self, project_id: str, task_id: str) -> Task:
+        """
+        タスクのステータスを「作業中」に変更します。
+
+        Notes:
+            * 現在タスクを担当しているユーザーのみ、この操作を行うことができます。
+            * 現在の状態が未着手(not_started)、休憩中(break)、保留(on_hold)のいずれかであるタスクに対してのみ、この操作を行うことができます。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+
+        Returns:
+            変更後のタスク
+        """
+        task, _ = self.api.get_task(project_id, task_id)
+        request_body = {
+            "status": TaskStatus.WORKING.value,
+            "account_id": self.api.account_id,
+            "last_updated_datetime": task["updated_datetime"],
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
+    def change_task_status_to_break(self, project_id: str, task_id: str) -> Task:
+        """
+        タスクのステータスを「休憩中」に変更します。
+
+        Notes:
+            * 現在タスクを担当しているユーザーのみ、この操作を行うことができます。
+            * 現在の状態が作業中(working)のタスクに対してのみ、この操作を行うことができます。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+
+        Returns:
+            変更後のタスク
+        """
+        task, _ = self.api.get_task(project_id, task_id)
+        request_body = {
+            "status": TaskStatus.BREAK.value,
+            "account_id": self.api.account_id,
+            "last_updated_datetime": task["updated_datetime"],
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
+    def change_task_status_to_on_hold(self, project_id: str, task_id: str) -> Task:
+        """
+        タスクのステータスを「保留」に変更します。
+
+        Notes:
+            * 現在タスクを担当しているユーザーのみ、この操作を行うことができます。
+            * 現在の状態が作業中(working)のタスクに対してのみ、この操作を行うことができます。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+
+        Returns:
+            変更後のタスク
+        """
+        task, _ = self.api.get_task(project_id, task_id)
+        request_body = {
+            "status": TaskStatus.ON_HOLD.value,
+            "account_id": self.api.account_id,
+            "last_updated_datetime": task["updated_datetime"],
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
+    def complete_task(self, project_id: str, task_id: str) -> Task:
+        """
+        今のフェーズを完了させ、 次のフェーズに遷移させます。
+        教師付フェーズのときはタスクを提出します。
+        検査／受入フェーズのときは、タスクを合格にします。
+
+
+        Notes:
+            * 現在タスクを担当しているユーザーのみ、この操作を行うことができます。
+            * 現在の状態が作業中(working)のタスクに対してのみ、この操作を行うことができます。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+
+        Returns:
+            変更後のタスク
+        """
+        task, _ = self.api.get_task(project_id, task_id)
+        request_body = {
+            "status": TaskStatus.COMPLETE.value,
+            "account_id": self.api.account_id,
+            "last_updated_datetime": task["updated_datetime"],
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
+    def cancel_submitted_task(self, project_id: str, task_id: str) -> Task:
+        """
+        タスクの提出を取り消します。
+        「提出されたタスク」とは以下の状態になっています。
+        * 教師付フェーズで「提出」ボタンを押して、検査/受入フェーズへ遷移したタスク
+        * 検査フェーズから「合格」ボタンを押して、受入フェーズへ遷移したタスク
+
+        Notes:
+            * 現在タスクを担当しているユーザーのみ、この操作を行うことができます。
+            * タスク提出後に検査/受入(抜取含む)等の作業が一切行われていない場合のみ、この操作を行うことができます。
+            * 現在の状態が未着手(not_started)のタスクに対してのみ、この操作を行うことができます。
+            * 現在のフェーズが検査(inspection)、もしくは受入(acceptance)のタスクに対してのみ、この操作を行うことができます。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+
+        Returns:
+            変更後のタスク
+        """
+        task, _ = self.api.get_task(project_id, task_id)
+        request_body = {
+            "status": TaskStatus.CANCELLED.value,
+            "account_id": self.api.account_id,
+            "last_updated_datetime": task["updated_datetime"],
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
+    def cancel_completed_task(self, project_id: str, task_id: str, operator_account_id: Optional[str] = None) -> Task:
+        """
+        タスクの受入完了状態を取り消す。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+            operator_account_id: 受入完了状態を取り消した後の担当者のaccount_id
+
+        Returns:
+            変更後のタスク
+        """
+
+        task, _ = self.api.get_task(project_id, task_id)
+
+        request_body = {
+            "status": TaskStatus.NOT_STARTED.value,
+            "account_id": operator_account_id,
+            "last_updated_datetime": task["updated_datetime"],
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
+    def change_task_operator(
+        self, project_id: str, task_id: str, operator_account_id: Optional[str] = None
+    ) -> Dict[str, Any]:
+        """
+        タスクの担当者を変更します。
+
+        Notes:
+            * プロジェクトオーナー(owner)、もしくは受入担当者(accepter)のみ、この操作を行うことができます。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+            operator_account_id: 新しい担当者のaccount_id。Noneの場合は、担当者を「未割り当て」にします。
+
+        Returns:
+            変更後のタスク
+
+        """
+        task, _ = self.api.get_task(project_id, task_id)
+
+        request_body = {
+            "status": TaskStatus.NOT_STARTED.value,
+            "account_id": operator_account_id,
+            "last_updated_datetime": task["updated_datetime"],
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
+    def reject_task(self, project_id: str, task_id: str, force: bool = False) -> Dict[str, Any]:
+        """
+        タスクを差し戻します。
+        * 通常の差し戻しの場合、タスクの担当者は未割り当てになります。
+        * 強制差し戻しの場合、タスクの担当者は直前の教師付フェーズの担当者になります。
+
+        Notes:
+            * 通常の差し戻しの場合
+                * 現在タスクを担当しているユーザーのみ、この操作を行うことができます。
+                * 現在の状態が作業中(working)のタスクに対してのみ、この操作を行うことができます。
+                * 現在のフェーズが検査(inspection)、もしくは受入(acceptance)のタスクに対してのみ、この操作を行うことができます。
+            * 強制差し戻しの場合
+                * タスクの状態・フェーズを無視して、フェーズを教師付け(annotation)に、状態を未作業(not started)に変更します。
+                * タスクの担当者としては、直前の教師付け(annotation)フェーズの担当者を割り当てます。
+                * この差戻しは、抜取検査・抜取受入のスキップ判定に影響を及ぼしません。
+
+        Args:
+            project_id: プロジェクトID
+            task_id: タスクID
+            force: Trueなら強制差し戻し、Falseなら通常の差し戻しを実施する
+
+        Returns:
+            変更後のタスク
+
+        """
+
+        task, _ = self.api.get_task(project_id, task_id)
+
+        request_body = {
+            "status": TaskStatus.REJECTED.value,
+            "account_id": self.api.account_id,
+            "last_updated_datetime": task["updated_datetime"],
+            "force": force,
+        }
+        updated_task, _ = self.api.operate_task(project_id, task_id, request_body=request_body)
+        return updated_task
+
     #########################################
     # Public Method : Instruction
     #########################################
@@ -1545,7 +1771,6 @@ class Wrapper:
     def get_all_project_job(self, project_id: str, query_params: Dict[str, Any]) -> List[JobInfo]:
         """
         すべてのバックグランドジョブを取得する。
-        2019/01時点でAPIが未実装のため、このメソッドも未実装。
 
         Args:
             project_id: プロジェクトID
@@ -1554,15 +1779,11 @@ class Wrapper:
         Returns:
             すべてのバックグランドジョブ一覧
         """
-
-        # return self._get_all_objects(self.api.get_project_job,
-        #                              limit=200,
-        #                              project_id=project_id, query_params=query_params)
-        #
         copied_params = copy.deepcopy(query_params) if query_params is not None else {}
 
         all_jobs: List[Dict[str, Any]] = []
         limit = 200
+        # クエリパラメタ`page`が未実装なため、`1`を指定する
         copied_params.update({"page": 1, "limit": limit})
         r = self.api.get_project_job(project_id, query_params=copied_params)[0]
         all_jobs.extend(r["list"])
@@ -1685,13 +1906,25 @@ class Wrapper:
         to_date: Optional[str] = None,
     ) -> List[Dict[str, Any]]:
         """
-        実績作業時間(actual_worktime)と予定作業時間(plan_worktime)を取得する。
+        実績作業時間(actual_worktime)と予定作業時間(plan_worktime)を扱いやすいフォーマットで取得する。
+        ただし、organization_id または project_id のいずれかを指定する必要がある。
 
         Args:
-            query_params:
+            organization_id: 絞り込み対象の組織ID
+            project_id: 絞り込み対象のプロジェクトID
+            account_id: 絞り込み対象のアカウントID
+            from_date: 絞り込み対象の開始日（YYYY-MM-DD）
+            to_date: 絞り込み対象の終了日（YYYY-MM-DD）
 
         Returns:
-
+            労務管理情報
+                * organization_id
+                * project_id
+                * account_id
+                * date
+                * actual_worktime：実績作業時間[hour]
+                * plan_worktime：予定作業時間[hour]
+                * working_description：実績に関するコメント
         """
 
         def _to_new_data(labor: Dict[str, Any]) -> Dict[str, Any]:
@@ -1701,6 +1934,9 @@ class Wrapper:
             labor.pop("values", None)
             return labor
 
+        if organization_id is None and project_id is None:
+            raise ValueError("one of the arguments organization_id project_id is required")
+
         query_params = {
             "organization_id": organization_id,
             "project_id": project_id,
@@ -1712,18 +1948,21 @@ class Wrapper:
         return [_to_new_data(e) for e in labor_list]
 
     def get_labor_control_availability(
-        self, account_id: str = None, from_date: Optional[str] = None, to_date: Optional[str] = None
+        self, account_id: str, from_date: Optional[str] = None, to_date: Optional[str] = None
     ) -> List[Dict[str, Any]]:
         """
         労務管理の予定稼働時間を取得する。
 
         Args:
-            account_id:
-            from_date:
-            to_date:
+            account_id: 絞り込み対象のアカウントID
+            from_date: 絞り込み対象の開始日（YYYY-MM-DD）
+            to_date: 絞り込み対象の終了日（YYYY-MM-DD）
 
         Returns:
             予定稼働時間情報
+                * account_id
+                * date
+                * availability：予定稼働時間[hour]
         """
 
         def _to_new_data(labor: Dict[str, Any]) -> Dict[str, Any]:
